summaryrefslogtreecommitdiffstats
path: root/tdecore/kicontheme.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'tdecore/kicontheme.cpp')
-rw-r--r--tdecore/kicontheme.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/tdecore/kicontheme.cpp b/tdecore/kicontheme.cpp
index abced574e..d985cc8b0 100644
--- a/tdecore/kicontheme.cpp
+++ b/tdecore/kicontheme.cpp
@@ -43,7 +43,7 @@ public:
TQString example, screenshot;
TQString linkOverlay, lockOverlay, zipOverlay, shareOverlay;
bool hidden;
- KSharedConfig::Ptr sharedConfig;
+ TDESharedConfig::Ptr sharedConfig;
};
/**
@@ -136,9 +136,9 @@ KIconTheme::KIconTheme(const TQString& name, const TQString& appName)
fileName = mDir + "index.theme";
mainSection="Icon Theme";
}
// Use KSharedConfig to avoid parsing the file many times, from each kinstance.
// Need to keep a ref to it to make this useful
- d->sharedConfig = KSharedConfig::openConfig( fileName, true /*readonly*/, false /*useKDEGlobals*/ );
+ d->sharedConfig = TDESharedConfig::openConfig( fileName, true /*readonly*/, false /*useKDEGlobals*/ );
TDEConfig& cfg = *d->sharedConfig;
//was: KSimpleConfig cfg(fileName);
@@ -136,9 +136,9 @@ KIconTheme::KIconTheme(const TQString& name, const TQString& appName)
mainSection="Icon Theme";
}
- // Use KSharedConfig to avoid parsing the file many times, from each kinstance.
+ // Use TDESharedConfig to avoid parsing the file many times, from each kinstance.
// Need to keep a ref to it to make this useful